@@ -3,7 +3,7 @@ Photonic crystal PWE/GME simulator with autograd support
 Monkey-patching numpy/autograd backend inspired by Floris Laporte's FDTD
 package at github.com/flaport/fdtd
 '''
-from .phc import Shape, Circle, Poly, Square, Hexagon
+from .phc import Shape, Circle, Poly, Square, Hexagon, FourierShape
 from .phc import PhotCryst, Layer, ShapesLayer, FreeformLayer, Lattice
 
 from . import gds
@@ -26,4 +26,4 @@ __all__ = ['GuidedModeExp',
            'Square', 
            'Hexagon']
 
-__version__ = '0.1.3'
+__version__ = '0.1.4'
